@@ -20,3 +20,6 @@ def validate_min_max_conn(min_conn: int, max_conn: int):
         raise ValueError("min_conn and max_conn must both be greater than or equal to zero")
     if min_conn >= max_conn:
         raise ValueError("min_conn must be strictly less than max_conn")
+
+def prune_body(body: dict) -> dict:
+    return {k: v for k, v in body.items() if v is not None}
